@@ -533,9 +533,8 @@ def get_extra_series(msgs: list, direction: int = 1, wantvers: Optional[int] = N
             continue
 
         if not lsub.reply:
-            payload = msg.get_payload(decode=True)
-            if isinstance(payload, bytes):
-                payload = payload.decode()
+            payload, charset = b4.LoreMessage.get_payload(msg)
+            if payload:
                 matches = re.search(r'^change-id:\s+(\S+)', payload, flags=re.I | re.M)
                 if matches:
                     logger.debug('Found change-id %s', matches.groups()[0])
